---
title: rateflow
sidebarTitle: rateflow
---

# `catalax.neural.plots.rateflow`

## Functions

### `plot_learned_rates` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/neural/plots/rateflow.py#L18" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
plot_learned_rates(rateflow_ode: RateFlowODE, dataset: Dataset, model: Model, show: bool = True, save_path: str | None = None, round_stoich: bool = True) -> Figure
```


Plot learned stoichiometry matrix, rates, and dataset for a trained RateFlowODE.

**Args:**
- `trained`: Trained RateFlowODE instance
- `dataset`: Dataset containing measurements
- `model`: Model instance with state information

